pub enum QuotaType {
NONE = 0,
FIFO = 1,
HARD = 2,
}Expand description
Quota type
NONE: No quota FIFO: When quota_size is reached, the oldest records are deleted HARD: When quota_size is reached, no more records can be added
Variants